# API
## `Spected(input, rules, [transformerFn])`

Validates data input against a set of validation rules and returns a result object containing error information for every provided data field.
Also works with deep nested objects.

#### Arguments

1. `input` *(Object)*: The data to be validated.

2. `rules` *(Object)*: An object of rules, consisting of arrays containing predicate function / error message tuple, f.e. `{name: [[a => a.length > 2, 'Minimum length 3.']]}`

3. `transformerFn` *(Function)*: Transform the result as needed, transformer is called when an input is invalid. Recieves an array of error messages.

```js
// errorCallback = ({errorMsgs}) => errorMsgs
{name: [], random: ['something is missing', 'invalid data']}

// errorCallback = ({errorMsgs}) => head(errorMsgs)
{name: [], random: 'something is missing']}
```

#### Returns
(Object): An object containg either true or depending on the transformer function a result representing the transformation.

```js
{
    name: true, 
    random: [
        'Minimum Random length of 8 is required.', 
        'Random should contain at least one uppercase letter.'
    ]
}
```

#### Example

```js
import spected from 'spected'

const validationRules = {
  name: [
    [isNotEmpty, 'Name should not be  empty.']
  ],
  random: [
    [isLengthGreaterThan(7), 'Minimum Random length of 8 is required.'],
    [hasCapitalLetter, 'Random should contain at least one uppercase letter.'],
  ]
}

const initialState = {name: 'foobar', random: 'r'}

spected(initialState, validationRules)
 
//  {
//      name: true, 
//      random: [
//          'Minimum Random length of 8 is required.', 
//          'Random should contain at least one uppercase letter.'
//      ]
//  }
   

```
